componenttools.get_improper_parentage_of_component
==================================================

.. autofunction:: abjad.tools.componenttools.get_improper_parentage_of_component.get_improper_parentage_of_component
